==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/th_TH.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "ไม่สามารถใช้พื้นที่จัดเก็บข้อมูลได้",
    "Storage invalid" : "การจัดเก็บข้อมูลไม่ถูกต้อง",
    "Unknown error" : "ข้อผิดพลาดที่ไม่ทราบสาเหตุ",
    "Unable to set upload directory." : "ไม่สามารถตั้งค่าอัพโหลดไดเรกทอรี",
    "Invalid Token" : "โทเค็นไม่ถูกต้อง",
    "No file was uploaded. Unknown error" : "ยังไม่มีไฟล์ใดที่ถูกอัพโหลด เกิดข้อผิดพลาดที่ไม่ทราบสาเหตุ",
    "There is no error, the file uploaded with success" : "ไม่พบข้อผิดพลาดใดๆ, ไฟล์ถูกอัพโหลดเรียบร้อยแล้ว",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "ขนาดไฟล์ที่อัพโหลดมีขนาดเกิน upload_max_filesize ที่ระบุไว้ใน php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ไฟล์ที่อัพโหลดมีขนาดไฟล์ใหญ่เกินจำนวนที่กำหนดไว้ในคำสั่ง MAX_FILE_SIZE ที่ถูกระบุไว้ในรูปแบบของ HTML",
    "The uploaded file was only partially uploaded" : "ไฟล์ถูกอัพโหลดได้เพียงบางส่วนเท่านั้น",
    "No file was uploaded" : "ไม่มีไฟล์ที่ถูกอัพโหลด",
    "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวเกิดการสูญหาย",
    "Failed to write to disk" : "เขียนข้อมูลลงแผ่นดิสก์ล้มเหลว",
    "Not enough storage available" : "เหลือพื้นที่ไม่เพียงสำหรับใช้งาน",
    "The target folder has been moved or deleted." : "โฟลเดอร์ปลายทางถูกย้ายหรือลบ",
    "Upload failed. Could not find uploaded file" : "อัพโหลดล้มเหลว ไม่สามารถหาไฟล์ที่จะอัพโหลด",
    "Upload failed. Could not get file info." : "อัพโหลดล้มเหลว ไม่สามารถรับข้อมูลไฟล์",
    "Invalid directory." : "ไดเร็กทอรี่ไม่ถูกต้อง",
    "Files" : "ไฟล์",
    "All files" : "ไฟล์ทั้งหมด",
    "Favorites" : "รายการโปรด",
    "Home" : "บ้าน",
    "Close" : "ปิด",
    "Upload cancelled." : "การอัพโหลดถูกยกเลิก",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ไม่สามารถอัพโหลด {filename} มันเป็นไดเรกทอรีหรือมี 0 ไบต์",
    "Total file size {size1} exceeds upload limit {size2}" : "ขนาดไฟล์ {size1} ทั้งหมดเกินขีดจำกัด ของการอัพโหลด {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "พื้นที่ว่างไม่เพียงพอคุณจะอัพโหลด {size1} แต่มีพืนที่แค่ {size2}",
    "Could not get result from server." : "ไม่สามารถรับผลลัพธ์จากเซิร์ฟเวอร์",
    "File upload is in progress. Leaving the page now will cancel the upload." : "การอัพโหลดไฟล์กำลังอยู่ในระหว่างดำเนินการ การออกจากหน้าเว็บนี้จะทำให้การอัพโหลดถูกยกเลิก",
    "Actions" : "การกระทำ",
    "Download" : "ดาวน์โหลด",
    "Rename" : "เปลี่ยนชื่อ",
    "Delete" : "ลบ",
    "Disconnect storage" : "ยกเลิกการเชื่อมต่อการจัดเก็บข้อมูล",
    "Unshare" : "ยกเลิกการแชร์",
    "Details" : "รายละเอียด",
    "Select" : "เลือก",
    "Pending" : "อยู่ระหว่างดำเนินการ",
    "Unable to determine date" : "ไม่สามารถกำหนดวัน",
    "This operation is forbidden" : "การดำเนินการนี้ถูกห้าม",
    "This directory is unavailable, please check the logs or contact the administrator" : "ไม่สามารถใช้งานไดเรกทอรีนี้โปรดตรวจสอบบันทึกหรือติดต่อผู้ดูแลระบบ",
    "Could not move \"{file}\", target exists" : "ไม่สามารถย้ายไฟล์ \"{file}\" ไม่มีไฟล์นั้นอยู่",
    "Could not move \"{file}\"" : "ไม่สามารถย้ายไฟล์ \"{file}\"",
    "{newName} already exists" : "{newName} มีอยู่แล้ว",
    "Could not rename \"{fileName}\", it does not exist any more" : "ไม่สามารถเปลี่ยนชื่อไฟล์ \"{fileName}\" ไฟล์นั้นไม่มีอยู่",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "ชื่อโฟลเดอร์ \"{targetName}\" มีอยู่แล้วใน \"{dir}\" กรุณาใช้ชื่อที่แตกต่างกัน",
    "Could not rename \"{fileName}\"" : "ไม่สามารถเปลี่ยนชื่อไฟล์ \"{fileName}\"",
    "Could not create file \"{file}\"" : "ไม่สามารถสร้างไฟล์ \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "ไม่สามารถสร้างไฟล์ \"{file}\" เพราะมันมีอยู่แล้ว",
    "Could not create folder \"{dir}\"" : "ไม่สามารถสร้างโฟลเดอร์ \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "ไม่สามารถสร้างโฟลเดอร์ \"{dir}\" เพราะมันมีอยู่แล้ว",
    "Error deleting file \"{fileName}\"." : "เกิดข้อผิดพลาดขณะลบไฟล์ \"{fileName}\"",
    "No entries in this folder match '{filter}'" : "ไม่มีรายการในโฟลเดอร์นี้ที่ตรงกับ '{filter}'",
    "Name" : "ชื่อ",
    "Size" : "ขนาด",
    "Modified" : "แก้ไขแล้ว",
    "_%n folder_::_%n folders_" : ["%n โฟลเดอร์"],
    "_%n file_::_%n files_" : ["%n ไฟล์"],
    "{dirs} and {files}" : "{dirs} และ {files}",
    "You don’t have permission to upload or create files here" : "คุณไม่ได้รับอนุญาตให้อัพโหลดหรือสร้างไฟล์ที่นี่",
    "_Uploading %n file_::_Uploading %n files_" : ["อัพโหลด %n ไฟล์"],
    "New" : "ใหม่",
    "\"{name}\" is an invalid file name." : "\"{name}\" เป็นชื่อไฟล์ที่ไม่ถูกต้อง",
    "File name cannot be empty." : "ชื่อไฟล์ไม่สามารถเว้นว่างได้",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของ {owner} เต็มแล้ว  ไฟล์ไม่สามารถอัพเดทหรือประสานข้อมูลได้อีก!",
    "Your storage is full, files can not be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของคุณเต็มแล้ว ไม่สามารถอัพเดทหรือประสานข้อมูลได้อีก!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "พื้นที่จัดเก็บข้อมูลของ {owner} ใกล้เต็มแล้ว\nใช้พื้นที่ไปแล้ว: ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "พื้นที่จัดเก็บข้อมูลของคุณใกล้เต็มแล้ว \nใช้พื้นที่ไปแล้ว: ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["ตรงกับ '{filter}'"],
    "Path" : "เส้นทาง",
    "_%n byte_::_%n bytes_" : ["%n ไบต์"],
    "Favorited" : "รายการโปรด",
    "Favorite" : "รายการโปรด",
    "Folder" : "แฟ้มเอกสาร",
    "New folder" : "โฟลเดอร์ใหม่",
    "{newname} already exists" : "{newname} ถูกใช้ไปแล้ว",
    "Upload" : "อัพโหลด",
    "An error occurred while trying to update the tags" : "เกิดข้อผิดพลาดขณะที่พยายามจะปรับปรุงแท็ก",
    "A new file or folder has been <strong>created</strong>" : "มีไฟล์ใหม่หรือโฟลเดอร์ได้ถูก <strong>สร้างขึ้น!</strong>",
    "A file or folder has been <strong>changed</strong>" : "มีไฟล์หรือโฟลเดอร์ได้ถูก <strong>เปลี่ยน!</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "จำกัดการแจ้งเตือนเกี่ยวกับการสร้างและการเปลี่ยนแปลงของคุณ <strong>ไฟล์ที่ชื่นชอบ</strong> <em>(สตรีมเท่านั้น)</em>",
    "A file or folder has been <strong>deleted</strong>" : "ไฟล์หรือโฟลเดอร์ถูก <strong>ลบ</strong>",
    "A file or folder has been <strong>restored</strong>" : "ไฟล์หรือโฟลเดอร์ถูก <strong>กู้คืน</strong>",
    "You created %1$s" : "คุณสร้าง %1$s",
    "%2$s created %1$s" : "%2$s สร้าง %1$s",
    "%1$s was created in a public folder" : "%1$s ถูกสร้างขึ้นในโฟลเดอร์สาธารณะ",
    "You changed %1$s" : "คุณทำการเปลี่ยนแปลง %1$s",
    "%2$s changed %1$s" : "%2$s ได้เปลี่ยนแปลง %1$s",
    "You deleted %1$s" : "คุณลบ %1$s ออก",
    "%2$s deleted %1$s" : "%2$s ลบ %1$s ออก",
    "You restored %1$s" : "คุณกู้คืน %1$s",
    "%2$s restored %1$s" : "%2$s ได้กู้คืน %1$s",
    "Changed by %2$s" : "เปลี่ยนแปลงโดย %2$s",
    "Deleted by %2$s" : "ลบโดย %2$s",
    "Restored by %2$s" : "กู้คืนโดย %2$s",
    "Upload (max. %s)" : "อัพโหลด (สูงสุด %s)",
    "File handling" : "การจัดการไฟล์",
    "Maximum upload size" : "ขนาดไฟล์สูงสุดที่อัพโหลดได้",
    "max. possible: " : "จำนวนสูงสุดที่สามารถทำได้: ",
    "Save" : "บันทึก",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "กับ PHP-FPM อาจใช้เวลา 5 นาทีสำหรับการเปลี่ยนแปลงที่ถูกนำมาใช้",
    "Missing permissions to edit from here." : "สิทธิ์ในการแก้ไขส่วนนี้หายไป",
    "Settings" : "ตั้งค่า",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "ใช้ที่อยู่นี้เพื่อ <a href=\"%s\" target=\"_blank\">เข้าถึงไฟล์ของคุณผ่าน WebDAV</a>",
    "Cancel upload" : "ยกเลิกการอัพโหลด",
    "No files in here" : "ไม่มีไฟล์ที่นี่",
    "Upload some content or sync with your devices!" : "อัพโหลดเนื้อหาบางส่วนหรือประสานข้อมูลกับอุปกรณ์ของคุณ! อีกครั้ง",
    "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
    "Select all" : "เลือกทั้งหมด",
    "Upload too large" : "ไฟล์ที่อัพโหลดมีขนาดใหญ่เกินไป",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ไฟล์ที่คุณพยายามที่จะอัพโหลดมีขนาดเกินกว่าขนาดสูงสุดที่กำหนดไว้ให้อัพโหลดได้สำหรับเซิร์ฟเวอร์นี้",
    "No favorites" : "ไม่มีรายการโปรด",
    "Files and folders you mark as favorite will show up here" : "ไฟล์และโฟลเดอร์ที่คุณทำเครื่องหมายเป็นรายการโปรดจะปรากฏขึ้นที่นี่",
    "Text file" : "ไฟล์ข้อความ",
    "New text file.txt" : "ไฟล์ข้อความใหม่ .txt"
},
"nplurals=1; plural=0;");

==> owncloud-9.1.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/th_TH.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "ไม่สามารถใช้พื้นที่จัดเก็บข้อมูลได้",
    "Storage invalid" : "การจัดเก็บข้อมูลไม่ถูกต้อง",
    "Unknown error" : "ข้อผิดพลาดที่ไม่ทราบสาเหตุ",
    "Unable to set upload directory." : "ไม่สามารถตั้งค่าอัพโหลดไดเรกทอรี",
    "Invalid Token" : "โทเค็นไม่ถูกต้อง",
    "No file was uploaded. Unknown error" : "ยังไม่มีไฟล์ใดที่ถูกอัพโหลด เกิดข้อผิดพลาดที่ไม่ทราบสาเหตุ",
    "There is no error, the file uploaded with success" : "ไม่พบข้อผิดพลาดใดๆ, ไฟล์ถูกอัพโหลดเรียบร้อยแล้ว",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "ขนาดไฟล์ที่อัพโหลดมีขนาดเกิน upload_max_filesize ที่ระบุไว้ใน php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ไฟล์ที่อัพโหลดมีขนาดไฟล์ใหญ่เกินจำนวนที่กำหนดไว้ในคำสั่ง MAX_FILE_SIZE ที่ถูกระบุไว้ในรูปแบบของ HTML",
    "The uploaded file was only partially uploaded" : "ไฟล์ถูกอัพโหลดได้เพียงบางส่วนเท่านั้น",
    "No file was uploaded" : "ไม่มีไฟล์ที่ถูกอัพโหลด",
    "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวเกิดการสูญหาย",
    "Failed to write to disk" : "เขียนข้อมูลลงแผ่นดิสก์ล้มเหลว",
    "Not enough storage available" : "เหลือพื้นที่ไม่เพียงสำหรับใช้งาน",
    "The target folder has been moved or deleted." : "โฟลเดอร์ปลายทางถูกย้ายหรือลบ",
    "Upload failed. Could not find uploaded file" : "อัพโหลดล้มเหลว ไม่สามารถหาไฟล์ที่จะอัพโหลด",
    "Upload failed. Could not get file info." : "อัพโหลดล้มเหลว ไม่สามารถรับข้อมูลไฟล์",
    "Invalid directory." : "ไดเร็กทอรี่ไม่ถูกต้อง",
    "Files" : "ไฟล์",
    "All files" : "ไฟล์ทั้งหมด",
    "File could not be found" : "ไม่พบไฟล์ในระบบ",
    "Home" : "บ้าน",
    "Close" : "ปิด",
    "Favorites" : "รายการโปรด",
    "Upload cancelled." : "การอัพโหลดถูกยกเลิก",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ไม่สามารถอัพโหลด {filename} มันเป็นไดเรกทอรีหรือมี 0 ไบต์",
    "Total file size {size1} exceeds upload limit {size2}" : "ขนาดไฟล์ {size1} ทั้งหมดเกินขีดจำกัด ของการอัพโหลด {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "พื้นที่ว่างไม่เพียงพอคุณจะอัพโหลด {size1} แต่มีพืนที่แค่ {size2}",
    "Error uploading file \"{fileName}\": {message}" : "ข้อผิดพลาดขณะอัพโหลดไฟล์ \"{fileName}\": {message}",
    "Could not get result from server." : "ไม่สามารถรับผลลัพธ์จากเซิร์ฟเวอร์",
    "Uploading..." : "กำลังอัพโหลด...",
    "..." : "...",
    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "เหลือเวลาอีก {hours} ชั่วโมง : {minutes} นาที : {seconds} วินาที",
    "{hours}:{minutes}h" : "{hours} ชั่วโมง : {minutes} นาที",
    "{minutes}:{seconds} minute{plural_s} left" : "เหลือเวลาอีก {minutes} นาที : {seconds} วินาที",
    "{minutes}:{seconds}m" : "{minutes} นาที : {seconds} วินาที",
    "{seconds} second{plural_s} left" : "เหลือเวลาอีก {seconds} วินาที",
    "{seconds}s" : "{seconds} วินาที",
    "Any moment now..." : "ช่วงเวลาใด ในตอนนี้...",
    "Soon..." : "เร็วๆ นี้...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} จาก {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "การอัพโหลดไฟล์กำลังอยู่ในระหว่างดำเนินการ การออกจากหน้าเว็บนี้จะทำให้การอัพโหลดถูกยกเลิก",
    "Actions" : "การกระทำ",
    "Download" : "ดาวน์โหลด",
    "Rename" : "เปลี่ยนชื่อ",
    "Delete" : "ลบ",
    "Disconnect storage" : "ยกเลิกการเชื่อมต่อการจัดเก็บข้อมูล",
    "Unshare" : "ยกเลิกการแชร์",
    "Details" : "รายละเอียด",
    "Select" : "เลือก",
    "Pending" : "อยู่ระหว่างดำเนินการ",
    "Unable to determine date" : "ไม่สามารถกำหนดวัน",
    "This operation is forbidden" : "การดำเนินการนี้ถูกห้าม",
    "This directory is unavailable, please check the logs or contact the administrator" : "ไม่สามารถใช้งานไดเรกทอรีนี้โปรดตรวจสอบบันทึกหรือติดต่อผู้ดูแลระบบ",
    "Could not move \"{file}\", target exists" : "ไม่สามารถย้ายไฟล์ \"{file}\" ไม่มีไฟล์นั้นอยู่",
    "Could not move \"{file}\"" : "ไม่สามารถย้ายไฟล์ \"{file}\"",
    "{newName} already exists" : "{newName} มีอยู่แล้ว",
    "Could not rename \"{fileName}\", it does not exist any more" : "ไม่สามารถเปลี่ยนชื่อไฟล์ \"{fileName}\" ไฟล์นั้นไม่มีอยู่",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "ชื่อโฟลเดอร์ \"{targetName}\" มีอยู่แล้วใน \"{dir}\" กรุณาใช้ชื่อที่แตกต่างกัน",
    "Could not rename \"{fileName}\"" : "ไม่สามารถเปลี่ยนชื่อไฟล์ \"{fileName}\"",
    "Could not create file \"{file}\"" : "ไม่สามารถสร้างไฟล์ \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "ไม่สามารถสร้างไฟล์ \"{file}\" เพราะมันมีอยู่แล้ว",
    "Could not create folder \"{dir}\"" : "ไม่สามารถสร้างโฟลเดอร์ \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "ไม่สามารถสร้างโฟลเดอร์ \"{dir}\" เพราะมันมีอยู่แล้ว",
    "Error deleting file \"{fileName}\"." : "เกิดข้อผิดพลาดขณะลบไฟล์ \"{fileName}\"",
    "No entries in this folder match '{filter}'" : "ไม่มีรายการในโฟลเดอร์นี้ที่ตรงกับ '{filter}'",
    "Name" : "ชื่อ",
    "Size" : "ขนาด",
    "Modified" : "แก้ไขเมื่อ",
    "_%n folder_::_%n folders_" : ["%n โฟลเดอร์"],
    "_%n file_::_%n files_" : ["%n ไฟล์"],
    "{dirs} and {files}" : "{dirs} และ {files}",
    "You don’t have permission to upload or create files here" : "คุณไม่ได้รับอนุญาตให้อัพโหลดหรือสร้างไฟล์ที่นี่",
    "_Uploading %n file_::_Uploading %n files_" : ["อัพโหลด %n ไฟล์"],
    "New" : "ใหม่",
    "\"{name}\" is an invalid file name." : "\"{name}\" เป็นชื่อไฟล์ที่ไม่ถูกต้อง",
    "File name cannot be empty." : "ชื่อไฟล์ไม่สามารถเว้นว่างได้",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของ {owner} เต็มแล้ว  ไฟล์ไม่สามารถอัพเดทหรือประสานข้อมูลได้อีก!",
    "Your storage is full, files can not be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของคุณเต็มแล้ว ไม่สามารถอัพเดทหรือประสานข้อมูลได้อีก!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "พื้นที่จัดเก็บข้อมูลของ {owner} ใกล้เต็มแล้ว\nใช้พื้นที่ไปแล้ว: ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "พื้นที่จัดเก็บข้อมูลของคุณใกล้เต็มแล้ว \nใช้พื้นที่ไปแล้ว: ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["ตรงกับ '{filter}'"],
    "Path" : "เส้นทาง",
    "_%n byte_::_%n bytes_" : ["%n ไบต์"],
    "Favorited" : "รายการโปรด",
    "Favorite" : "รายการโปรด",
    "Folder" : "แฟ้มเอกสาร",
    "New folder" : "โฟลเดอร์ใหม่",
    "{newname} already exists" : "{newname} ถูกใช้ไปแล้ว",
    "Upload" : "อัพโหลด",
    "An error occurred while trying to update the tags" : "เกิดข้อผิดพลาดขณะที่พยายามจะอัพเดทแท็ก",
    "A new file or folder has been <strong>created</strong>" : "มีไฟล์ใหม่หรือโฟลเดอร์ได้ถูก <strong>สร้างขึ้น!</strong>",
    "A file or folder has been <strong>changed</strong>" : "มีไฟล์หรือโฟลเดอร์ได้ถูก <strong>เปลี่ยน!</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "จำกัดการแจ้งเตือนเกี่ยวกับการสร้างและการเปลี่ยนแปลงของคุณ <strong>ไฟล์ที่ชื่นชอบ</strong> <em>(สตรีมเท่านั้น)</em>",
    "A file or folder has been <strong>deleted</strong>" : "ไฟล์หรือโฟลเดอร์ถูก <strong>ลบ</strong>",
    "A file or folder has been <strong>restored</strong>" : "ไฟล์หรือโฟลเดอร์ถูก <strong>กู้คืน</strong>",
    "You created %1$s" : "คุณสร้าง %1$s",
    "%2$s created %1$s" : "%2$s สร้าง %1$s",
    "%1$s was created in a public folder" : "%1$s ถูกสร้างขึ้นในโฟลเดอร์สาธารณะ",
    "You changed %1$s" : "คุณทำการเปลี่ยนแปลง %1$s",
    "%2$s changed %1$s" : "%2$s ได้เปลี่ยนแปลง %1$s",
    "You deleted %1$s" : "คุณลบ %1$s ออก",
    "%2$s deleted %1$s" : "%2$s ลบ %1$s ออก",
    "You restored %1$s" : "คุณกู้คืน %1$s",
    "%2$s restored %1$s" : "%2$s ได้กู้คืน %1$s",
    "Changed by %2$s" : "เปลี่ยนแปลงโดย %2$s",
    "Deleted by %2$s" : "ลบโดย %2$s",
    "Restored by %2$s" : "กู้คืนโดย %2$s",
    "Upload (max. %s)" : "อัพโหลด (สูงสุด %s)",
    "File handling" : "การจัดการไฟล์",
    "Maximum upload size" : "ขนาดไฟล์สูงสุดที่สามารถอัพโหลดได้",
    "max. possible: " : "จำนวนสูงสุดที่สามารถทำได้: ",
    "Save" : "บันทึก",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "หากใช้ร่วมกับ PHP-FPM อาจใช้เวลาเปลี่ยนแปลงประมาณ 5 นาที",
    "Missing permissions to edit from here." : "สิทธิ์ในการแก้ไขส่วนนี้หายไป",
    "Settings" : "ตั้งค่า",
    "Show hidden files" : "แสดงไฟล์ที่ซ่อนอยู่",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "ใช้ที่อยู่นี้เพื่อ <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">เข้าถึงไฟล์ของคุณผ่าน WebDAV</a>",
    "No files in here" : "ไม่มีไฟล์ที่นี่",
    "Upload some content or sync with your devices!" : "อัพโหลดเนื้อหาบางส่วนหรือประสานข้อมูลกับอุปกรณ์ของคุณ! อีกครั้ง",
    "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
    "Select all" : "เลือกทั้งหมด",
    "Upload too large" : "ไฟล์ที่อัพโหลดมีขนาดใหญ่เกินไป",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ไฟล์ที่คุณพยายามที่จะอัพโหลดมีขนาดเกินกว่าขนาดสูงสุดที่กำหนดไว้ให้อัพโหลดได้สำหรับเซิร์ฟเวอร์นี้",
    "No favorites" : "ยังไม่มีรายการโปรด",
    "Files and folders you mark as favorite will show up here" : "ไฟล์และโฟลเดอร์ที่คุณทำเครื่องหมายเป็นรายการโปรดจะปรากฏขึ้นที่นี่",
    "Text file" : "ไฟล์ข้อความ",
    "New text file.txt" : "ไฟล์ข้อความใหม่ .txt"
},
"nplurals=1; plural=0;");
